import os, inspect, tarfile
from pathlib import Path
import importlib.util
import ork.path, ork.host
from ork.command import Command, run
from ork.deco import Deco
from ork.wget import wget
from ork import pathtools, cmake, make, path, git, host

deco = Deco()

###############################################################################

def downloadAndExtract(urls,
                       outname,
                       archive_type,
                       md5val,
                       build_dest,
                       arc_options=[]):

  arcpath = wget( urls = urls,
                  output_name = outname,
                  md5val = md5val )


  if arcpath:
    if build_dest.exists():
      Command(["rm","-rf",build_dest]).exec()
    print("extracting<%s> to build_dest<%s>"%(deco.path(arcpath),deco.path(build_dest)))
    print(archive_type)
    build_dest.mkdir()
    if( archive_type=="zip" ):
        os.chdir(str(build_dest))
        Command(["unzip"]+arc_options+[arcpath]).exec()
    elif archive_type=="tgz":
        os.chdir(str(build_dest))
        Command(["tar","xvf",arcpath]).exec()
    elif archive_type=="none":
        os.chdir(str(build_dest))
        run(["cp",arcpath,build_dest/outname],do_log=True)
        pass
    else:
        print(arcpath)
        #assert(tarfile.is_tarfile(str(arcpath)))
        tf = tarfile.open(str(arcpath),mode='r:%s'%archive_type)
        tf.extractall(path=str(build_dest))

  return arcpath



###############################################################################
# Orkid Build System
# Copyright 2010-2020, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, inspect, tarfile
from pathlib import Path
import importlib.util
import ork.path, ork.host
from ork.command import Command, run
from ork.deco import Deco
from ork.wget import wget
from ork import pathtools, cmake, make, path, git, host, _globals
from ork._dep_fetch import *
from ork._dep_build import *
from ork._dep_provider import *
from ork._dep_impl import *
from ork._dep_node import *
from ork._dep_dl import *
from ork._dep_x import *
from ork._dep_enumerate import *



###############################################################################
# Orkid Build System
# Copyright 2010-2018, Michael T. Mayers
# email: michael@tweakoz.com
# The Orkid Build System is published under the GPL 2.0 license
# see http://www.gnu.org/licenses/gpl-2.0.html
###############################################################################

import os, sys

###############################################################################

class Manifest:
	def __init__(self,name):
		self.name = name
		self.depends = list()
		self.scripts_folder = None
		self.manifest_root= None

	def add_dep(self,depname):
		self.depends.append(depname)

###############################################################################

class ManifestsContainer:
	def __init__(self):
		self.manifests = dict()
	def add_project(self,name):
		found = self.manifests.get(name)
		if found==None:
			found = self.manifests[name]=Manifest(name)
		else:
			print("ERROR: project<%s> already found" % name)
		return found

	def depends(self,name,depname):
		prj = self.manifests.get(name)
		dep = self.manifests.get(depname)
		if (prj!=None) and (dep!=None):
			prj.add_dep(dep)
		else:
			print("ERROR: prj<%s> or dep<%s> not found" % (name,depname))

###############################################################################

manifests = ManifestsContainer()



from setuptools import setup, find_packages
import glob

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name='ork.build.tools',
    version = '0.0.1',
    packages=find_packages(where='scripts'),
    package_dir={'': 'scripts'},
    package_data={'ork.build.tools': ['bin_priv/*']},
    scripts=glob.glob('bin_pub/*'),
    long_description=long_description,
    long_description_content_type='text/markdown')
